@@ -1,5 +1,6 @@
 require(rms)
-data(cancer, package='survival')
+require(survival)
+data(cancer)
 f <- cph(Surv(time, status) ~ age, data=cancer, x=TRUE, y=TRUE, surv=TRUE,
          method='exact')
 validate(f, B=20)
